..
    This file is part of Invenio.
    Copyright (C) 2015-2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. include:: ../README.rst

.. toctree::
    :maxdepth: 2

    getting-started/index
    tutorials/bootcamp
    documentation/index
    community/index
    releases/index
